# PowerShell script to install the RLM service

# Get the current working directory
$currentDirectory = Get-Location

# Construct the dynamic paths
$logPath = Join-Path -Path $currentDirectory -ChildPath "rlm.log"
$licensePath = Join-Path -Path $currentDirectory -ChildPath "license\license.lic"

# Check if the license file exists
if (-not (Test-Path -Path $licensePath)) {
    Write-Host "Cannot install the RLM service. The license file 'license\license.lic' does not exist." -ForegroundColor Yellow
    Write-Host "Please edit the license file provided replacing the hostname and copy the file to 'license\license.lic'." -ForegroundColor Yellow
    exit
}

# Command parameters
$serviceName = "DCV-RLM"
$serviceUserName = Read-Host "Please enter the service user name (leave blank if not applicable)"
$servicePassword = if ($serviceUserName) { Read-Host "Please enter the service password" } else { $null }

# Construct the command
$command = ".\rlm.exe -nows -dlog `"$logPath`" -c `"$licensePath`" -install_service -service_name $serviceName"
if ($serviceUserName) {
    $command += " -user `"$serviceUserName`" -password `"$servicePassword`""
}

# Output the command to be run
Write-Host "The following command will be executed:"
Write-Host $command

# Ask the user for confirmation
$response = Read-Host "Do you want to execute this command? (yes/no)"

if ($response -eq "yes") {
    # Execute the command
    Invoke-Expression $command
} else {
    Write-Host "Command execution cancelled."
}

